**************
Learning rules
**************

These learning rule types can be used in any place that
`Nengo learning rule types
<https://www.nengo.ai/nengo/frontend_api.html#learning-rule-types>`_
can be used.

.. default-role:: obj

.. autoclass:: nengo_extras.learning_rules.AML

.. autoclass:: nengo_extras.learning_rules.DeltaRule
